/************************************************************************/
/*                                                                      */
/*      Tile Tabs WE - Generic WebExtension - Open Layout Page          */
/*                                                                      */
/*      Javascript for Open Layout Page                                 */
/*                                                                      */
/*      Last Edit - 23 Sep 2017                                         */
/*                                                                      */
/*      Copyright (C) 2015-2017 DW-dev                                  */
/*                                                                      */
/*      Distributed under the GNU General Public License version 2      */
/*      See LICENCE.txt file and http://www.gnu.org/licenses/           */
/*                                                                      */
/************************************************************************/

/************************************************************************/
/*                                                                      */
/* Refer to Google Chrome developer documentation:                      */
/*                                                                      */
/*  https://developer.chrome.com/extensions/messaging                   */
/*                                                                      */
/*  https://developer.chrome.com/extensions/runtime                     */
/*  https://developer.chrome.com/extensions/storage                     */
/*                                                                      */
/************************************************************************/

"use strict";

/************************************************************************/

/* Global variables */

var isFirefox;

var platformOS;

/************************************************************************/

/* Listener for open layout page load */

document.addEventListener("DOMContentLoaded",onLoadPage,false);

/************************************************************************/

/* Initialize on page load */

function onLoadPage()
{
    document.addEventListener("mousedown",onMouseDown,false);
    document.getElementById("open-buttons-open").addEventListener("click",onOpen,false);
    document.getElementById("open-buttons-cancel").addEventListener("click",onCancel,false);
    
    chrome.storage.local.get(null,
    function(object)
    {
        var i,j,select,layoutName,layoutString,layoutType,windowCount,option;
        var keys = new Array();
        
        /* Load environment */
        
        isFirefox = object["environment-isfirefox"];
        
        platformOS = object["environment-platformos"];
        
        document.body.setAttribute("platformos",platformOS);
        
        select = document.getElementById("open-layoutlist-select");
        
        /* Normal layouts */
        
        keys = Object.keys(object).sort();
        
        for (i = 0; i < keys.length; i++)
        {
            if (keys[i].substr(0,14) != "layout-string-") continue;
            
            layoutName = keys[i].substr(14);
            
            layoutString = object[keys[i]];
            
            j = layoutString.indexOf(",");
            layoutType = +layoutString.substr(0,j);
            layoutString = layoutString.substr(j+1);
            
            j = layoutString.indexOf(";");
            windowCount = +layoutString.substr(0,j);
            
            option = document.createElement("option");
            
            option.setAttribute("value",layoutName);
            option.setAttribute("title",layoutName.replace(/~/g," "));
            
            if (layoutName.length <= 25)
            {
                option.text = layoutName.replace(/~/g,"\u00A0") + "\u00A0";
                for (j = 0; j < 25-layoutName.length; j++) option.text += "\u00A0";
            }
            else option.text = layoutName.replace(/~/g,"\u00A0").substr(0,25) + "\u2026";
            
            if (!isFirefox) option.text += "\u00A0";
            
            if (windowCount < 10) option.text += "\u00A0";
            
            option.text += "\u00A0\u00A0\u00A0" + windowCount;
            
            if (layoutType == 1 || layoutType == 3) option.text += "\u00A0\u00A0\u00A0\u00A0" + "\u25CF";
            
            select.appendChild(option);
        }
    });
}

/************************************************************************/

/* Hide message */

function onMouseDown(event)
{
    document.getElementById("open-message-1").style.setProperty("display","none","");
}

/************************************************************************/

/* Open layout */

function onOpen(event)
{
    var select;
    
    select = document.getElementById("open-layoutlist-select");
    
    if (select.options.length == 0 || select.selectedIndex == -1)
    {
        document.getElementById("open-message-1").style.setProperty("display","inline","");
        event.preventDefault();
        return;
    }
    
    chrome.runtime.sendMessage({ type: "openLayout_Reply", layoutName: select.options[select.selectedIndex].getAttribute("value"), result: true });
}

/************************************************************************/

/* Cancel operation */

function onCancel(event)
{
    chrome.runtime.sendMessage({ type: "openLayout_Reply", result: false });
}

/************************************************************************/
