/************************************************************************/
/*                                                                      */
/*      Tile Tabs WE - Generic WebExtension - Options Page              */
/*                                                                      */
/*      Javascript for Options Page                                     */
/*                                                                      */
/*      Last Edit - 03 Mar 2018                                         */
/*                                                                      */
/*      Copyright (C) 2015-2018 DW-dev                                  */
/*                                                                      */
/*      Distributed under the GNU General Public License version 2      */
/*      See LICENCE.txt file and http://www.gnu.org/licenses/           */
/*                                                                      */
/************************************************************************/

/************************************************************************/
/*                                                                      */
/*  Refer to Google Chrome developer documentation:                     */
/*                                                                      */
/*  https://developer.chrome.com/extensions/optionsV2                   */
/*                                                                      */
/*  https://developer.chrome.com/extensions/storage                     */
/*                                                                      */
/************************************************************************/

"use strict";

/************************************************************************/

/* Global variables */

/************************************************************************/

/* Listener for options page load */

document.addEventListener("DOMContentLoaded",onLoadPage,false);

/************************************************************************/

/* Load options */

function onLoadPage(event)
{
    /* Load options from local storage */
    
    chrome.storage.local.get(null,
    function(object)
    {
        /* General options */
        
        document.getElementById("options-showsubmenu").checked = object["options-showsubmenu"];
        document.getElementById("options-showquickmenu").checked = object["options-showquickmenu"];
        document.getElementById("options-showtoolbars").checked = object["options-showtoolbars"];
        document.getElementById("options-settoggleall").checked = object["options-settoggleall"];
        
        document.getElementById("options-assignexist").checked = object["options-assignexist"];
        document.getElementById("options-autocloseopen").checked = object["options-autocloseopen"];
        document.getElementById("options-autocloseuser").checked = object["options-autocloseuser"];
        
        document.getElementById("options-topmargin").value = object["options-topmargin"];
        document.getElementById("options-lrbmarginnormal").value = object["options-lrbmarginnormal"];
        document.getElementById("options-lrbmarginpopup").value = object["options-lrbmarginpopup"];
        document.getElementById("options-maxadjust").value = object["options-maxadjust"];
        
        /* Page Settings options */
        
        document.getElementById("options-defaulttype").elements["type"].value = object["options-defaulttype"];
        document.getElementById("options-defaultpage").value = object["options-defaultpage"];
        
        document.getElementById("options-openlinks").elements["clicks"].value = object["options-openlinks"];
        
        document.getElementById("options-syncactive").checked = object["options-syncactive"];
        
        document.getElementById("options-defaultpage").disabled = !document.getElementById("options-custompage").checked;
    });
    
    /* Add listeners for click on tab buttons */
    
    document.getElementById("options-tabbar-general").addEventListener("click",showGeneralTab,false);
    document.getElementById("options-tabbar-pagesettings").addEventListener("click",showPageSettingsTab,false);
    
    /* Add listeners for click on default page radio buttons */
    
    document.getElementById("options-newtabpage").addEventListener("click",onClickDefaultType,false);
    document.getElementById("options-blankpage").addEventListener("click",onClickDefaultType,false);
    document.getElementById("options-custompage").addEventListener("click",onClickDefaultType,false);
    
    /* Add listener for click on save button */
    
    document.getElementById("options-save-button").addEventListener("click",onClickSave,false);
    
    /* Wait for page layout to complete */
    
    document.getElementById("options").style.setProperty("opacity","0","");
    
    window.setTimeout(
    function()
    {
        var width1,width2,height1,height2;
        
        /* Equalize widths of tabs */
        
        width1 = window.getComputedStyle(document.getElementById("options-tab-general"),null).getPropertyValue("width");
        width2 = window.getComputedStyle(document.getElementById("options-tab-pagesettings"),null).getPropertyValue("width");
        
        width1 = width1.substr(0,width1.length-2);
        width2 = width2.substr(0,width2.length-2);
        
        width1 = Math.max(width1,width2);
        
        document.getElementById("options-tab-general").style.setProperty("width",width1 + "px","");
        document.getElementById("options-tab-pagesettings").style.setProperty("width",width1 + "px","");
        
        /* Equalize heights of tabs */
        
        height1 = window.getComputedStyle(document.getElementById("options-tab-general"),null).getPropertyValue("height");
        height2 = window.getComputedStyle(document.getElementById("options-tab-pagesettings"),null).getPropertyValue("height");
        
        height1 = height1.substr(0,height1.length-2);
        height2 = height2.substr(0,height2.length-2);
        
        height1 = Math.max(height1,height2);
        
        document.getElementById("options-tab-general").style.setProperty("height",height1 + "px","");
        document.getElementById("options-tab-pagesettings").style.setProperty("height",height1 + "px","");
        
        /* Show general tab */
        
        showGeneralTab();
        
        document.getElementById("options").style.setProperty("opacity","1","");
    },50);
}

/************************************************************************/

/* Select tab */

function showGeneralTab(event)
{
    document.getElementById("options-tabbar-general").setAttribute("selected","");
    document.getElementById("options-tabbar-pagesettings").removeAttribute("selected");
    
    document.getElementById("options-tab-general").style.setProperty("display","block","");
    document.getElementById("options-tab-pagesettings").style.setProperty("display","none","");
}

function showPageSettingsTab(event)
{
    document.getElementById("options-tabbar-general").removeAttribute("selected");
    document.getElementById("options-tabbar-pagesettings").setAttribute("selected","");
    
    document.getElementById("options-tab-general").style.setProperty("display","none","");
    document.getElementById("options-tab-pagesettings").style.setProperty("display","block","");
}

/************************************************************************/

/* Enable or Disable options */

function onClickDefaultType(event)
{
    document.getElementById("options-defaultpage").disabled = !document.getElementById("options-custompage").checked;
}

/************************************************************************/

/* Save options */

function onClickSave(event)
{
    chrome.storage.local.set(
    {
        /* General options */
        
        "options-showsubmenu": document.getElementById("options-showsubmenu").checked,
        "options-showquickmenu": document.getElementById("options-showquickmenu").checked,
        "options-showtoolbars": document.getElementById("options-showtoolbars").checked,
        "options-settoggleall": document.getElementById("options-settoggleall").checked,
        
        "options-assignexist": document.getElementById("options-assignexist").checked,
        "options-autocloseopen": document.getElementById("options-autocloseopen").checked,
        "options-autocloseuser": document.getElementById("options-autocloseuser").checked,
        
        "options-topmargin": +document.getElementById("options-topmargin").value,
        "options-lrbmarginnormal": +document.getElementById("options-lrbmarginnormal").value,
        "options-lrbmarginpopup": +document.getElementById("options-lrbmarginpopup").value,
        "options-maxadjust": +document.getElementById("options-maxadjust").value,
        
        /* Page Settings options */
        
        "options-defaulttype": document.getElementById("options-defaulttype").elements["type"].value,
        "options-defaultpage": document.getElementById("options-defaultpage").value,
        
        "options-openlinks": document.getElementById("options-openlinks").elements["clicks"].value,
        
        "options-syncactive": document.getElementById("options-syncactive").checked
    });
    
    /* Display saved status for short period */
    
    document.getElementById("options-save-status").style.setProperty("display","block","");
    
    setTimeout(function()
    {
        document.getElementById("options-save-status").style.setProperty("display","none","");
    }
    ,1000);
}

/************************************************************************/
