/************************************************************************/
/*                                                                      */
/*      Tile Tabs WE - Generic WebExtension - Save Layout Page          */
/*                                                                      */
/*      Javascript for Save Layout Page                                 */
/*                                                                      */
/*      Last Edit - 23 Sep 2017                                         */
/*                                                                      */
/*      Copyright (C) 2015-2017 DW-dev                                  */
/*                                                                      */
/*      Distributed under the GNU General Public License version 2      */
/*      See LICENCE.txt file and http://www.gnu.org/licenses/           */
/*                                                                      */
/************************************************************************/

/************************************************************************/
/*                                                                      */
/* Refer to Google Chrome developer documentation:                      */
/*                                                                      */
/*  https://developer.chrome.com/extensions/messaging                   */
/*                                                                      */
/*  https://developer.chrome.com/extensions/runtime                     */
/*  https://developer.chrome.com/extensions/storage                     */
/*                                                                      */
/************************************************************************/

"use strict";

/************************************************************************/

/* Global variables */

var isFirefox;

var platformOS;

var replaceState;

/************************************************************************/

/* Listener for save layout page load */

document.addEventListener("DOMContentLoaded",onLoadPage,false);

/************************************************************************/

/* Initialize on page load */

function onLoadPage()
{
    replaceState = 0;
    
    document.addEventListener("mousedown",onMouseDown,false);
    document.getElementById("save-layoutlist-select").addEventListener("change",onSelect,false);
    document.getElementById("save-buttons-save").addEventListener("click",onSave,false);
    document.getElementById("save-buttons-cancel").addEventListener("click",onCancel,false);
    
    chrome.storage.local.get(null,
    function(object)
    {
        var i,j,select,input,savetabs,layoutName,layoutString,layoutType,windowCount,option;
        var keys = new Array();
        
        /* Load environment */
        
        isFirefox = object["environment-isfirefox"];
        
        platformOS = object["environment-platformos"];
        
        document.body.setAttribute("platformos",platformOS);
        
        select = document.getElementById("save-layoutlist-select");
        input = document.getElementById("save-layoutname-input");
        savetabs = document.getElementById("save-savetabs-checkbox");
        
        input.focus();
        
        /* Normal layouts */
        
        keys = Object.keys(object).sort();
        
        for (i = 0; i < keys.length; i++)
        {
            if (keys[i].substr(0,14) != "layout-string-") continue;
            
            layoutName = keys[i].substr(14);
            
            layoutString = object[keys[i]];
            
            j = layoutString.indexOf(",");
            layoutType = +layoutString.substr(0,j);
            layoutString = layoutString.substr(j+1);
            
            j = layoutString.indexOf(";");
            windowCount = +layoutString.substr(0,j);
            
            option = document.createElement("option");
            
            option.setAttribute("value",layoutName);
            option.setAttribute("title",layoutName.replace(/~/g," "));
            
            if (layoutName.length <= 25)
            {
                option.text = layoutName.replace(/~/g,"\u00A0") + "\u00A0";
                for (j = 0; j < 25-layoutName.length; j++) option.text += "\u00A0";
            }
            else option.text = layoutName.replace(/~/g,"\u00A0").substr(0,25) + "\u2026";
            
            if (!isFirefox) option.text += "\u00A0";
            
            if (windowCount < 10) option.text += "\u00A0";
            
            option.text += "\u00A0\u00A0\u00A0" + windowCount;
            
            if (layoutType == 1 || layoutType == 3) option.text += "\u00A0\u00A0\u00A0\u00A0" + "\u25CF";
            
            select.appendChild(option);
        }
        
        savetabs.checked = object["layout-savetabs"];
    });
}

/************************************************************************/

/* Hide messages */

function onMouseDown(event)
{
    document.getElementById("save-message-1").style.setProperty("display","none","");
    document.getElementById("save-message-2").style.setProperty("display","none","");
    document.getElementById("save-message-3").style.setProperty("display","none","");
    
    if (replaceState == 1)
    {
        document.getElementById("save-buttons-save").innerText = "Save";
        replaceState = 2;
    }
    else if (replaceState == 2) replaceState = 0;
}

/************************************************************************/

/* Select layout */

function onSelect(event)
{
    var select,input;
    
    select = document.getElementById("save-layoutlist-select");
    input = document.getElementById("save-layoutname-input");
    
    input.value = select.options[select.selectedIndex].getAttribute("value").replace(/~/g," ");
    
    input.focus();
}

/************************************************************************/

/* Save layout */

function onSave(event)
{
    var i,select,input,savetabs;
    
    select = document.getElementById("save-layoutlist-select");
    input = document.getElementById("save-layoutname-input");
    savetabs = document.getElementById("save-savetabs-checkbox");
    
    if (input.value.length == 0)
    {
        document.getElementById("save-message-1").style.setProperty("display","inline","");
        event.preventDefault();
        return;
    }
    
    if (input.value.match(/^[-_ a-zA-Z0-9]+$/) == null)
    {
        document.getElementById("save-message-2").style.setProperty("display","inline","");
        event.preventDefault();
        return;
    }
    
    if (replaceState != 2)
    {
        for (i = 0; i < select.options.length; i++)
        {
            if (input.value.replace(/ /g,"~") == select.options[i].getAttribute("value"))
            {
                document.getElementById("save-message-3").style.setProperty("display","inline","");
                
                document.getElementById("save-buttons-save").innerText = "Replace";
                replaceState = 1;
                
                event.preventDefault();
                return;
            }
        }
    }
    
    chrome.storage.local.set({ "layout-savetabs": savetabs.checked });
    
    chrome.runtime.sendMessage({ type: "saveLayout_Reply", layoutName: input.value.replace(/ /g,"~"), saveTabs: savetabs.checked, result: true });
}

/************************************************************************/

/* Cancel operation */

function onCancel(event)
{
    chrome.runtime.sendMessage({ type: "saveLayout_Reply", name: "", result: false });
}

/************************************************************************/
